subroutine run_extsym(filename, gof_value)
  USE DFPORT
  character(*), intent(in) :: filename
  double precision, intent(in) :: gof_value
  
  character (len = 10) chextcode
  integer :: nextcode
  character (len = 1) chext1
  
  double precision, parameter :: inflation_number = 1.0 ! how much to multiply GOF with

  integer sysreturn    ! used as return value when calling ExtSym
  
  
  !
  ! Ask user for extinction symbol

  write(*,5500)
  5500 format(/,' Please enter the code letters for the Laue class symbols:',/,/, &		
  '			o - orthorhombic ',/,&
  '			b - monoclinic (unique axis b)',/,&
  '			c - monoclinic (unique axis c)',/,&
  '			a - monoclinic (unique axis a)',/,&
  '			t - tetragonal',/,&
  '			r - trigonal (hexagonal axes and obverse setting)',/,&
  '			h - hexagonal',/,&
  '			d - cubic')

  5501	read(*,'(q,a)') nextcode,chextcode
	  chext1=chextcode(1:1)

	  if ( .not.(chext1 .eq. 'o' .or. chext1 .eq. 'b' .or. chext1 .eq. 'c' .or. chext1 .eq. 'a' .or. &
	  chext1 .eq. 't' .or. chext1 .eq. 'r' .or. chext1 .eq. 'h' .or. chext1 .eq. 'd' ) ) then
	  write(*,*) (' Unrecognised codeword - please retype')
	  goto 5501
	  end if
	  
	  
  ! Write to disk parameter_input.asc - a required ExtSym input file
  !
	  open(13,file='parameter_input.asc',status='unknown')
	  write(13,5601)
  5601	format(/,'Below simply specify the input data file name and the Laue class of the data.',/)
	  write(13,5611)
  5611 format(/,'INPUT DATA FILE:')
	  write(13,5602) trim(filename)
	  5602 format(a)
  !
	  write(13,5603) 
  5603 format(/,'LAUE CLASS:')
	  write(13,5604) chext1
	  5604 format(a)
  !
	  write(13,5605) 
  5605 format(/,'--------------------------------------------------------------------------------------',/)
  !
  write(13,5610)
  5610 format(' The possible Laue class symbols which can be used above are:',/,/, &		
  '			o - orthorhombic ',/,&
  '			b - monoclinic (unique axis b)',/,&
  '			c - monoclinic (unique axis c)',/,&
  '			a - monoclinic (unique axis a)',/,&
  '			t - tetragonal',/,&
  '			r - trigonal (hexagonal axes and obverse setting)',/,&
  '			h - hexagonal',/,&
  '			d - cubic')
	  close(13)


  ! create the advanced.asc file

	  open(13,file='advanced.asc',status='unknown')
	  write(13,6601)
  6601	format(/,'The parameters below can be used to affect the execution time of the program (with a',/, &
           'corresponding effect on the accuracy of the calculated numbers) and to modify the',/, &
           'errors of the powder data file, which filename is specified in parameter_input.asc',/,/, &
           'MODIFY INPUT DATA FILE',/, &
           '----------------------')    
      write(13, '(f8.4,a)') inflation_number*gof_value, '        (rescale errors, for explanation see +)'
      write(13, '(a)') ' '
      write(13, '(a)') ' '
      write(13, '(a)') 'ADJUST EXECUTION SPEED AND ACCURACY OF CALCULATED NUMBERS'
      write(13, '(a)') '--------------------------------------------------------'
      write(13, '(a)') '40              (correlation-cutoff value, for explanation see *)'
      write(13, '(a)') '500000          (max Monte Carlo iterations, for explanation see **)'
      write(13, '(a)') '2               (tolerance, for explanation see **)'
         
   	  write(13,6611)
  6611 format(/,/,'--------------------------------------------------------------------------------------',/,/, &
           'Short explanations:',/,/,/, &
           '+     multiply the standard deviations of the powder data file by this number',/, &
           '      (i.e. the square root of the diagonal elements of the correlation matrix)',/,/,/, &
           '*     the correlation-cutoff value is a threshold value. This number must be between',/, &
           '      0 and 100 and represents a percentage. If the correlation between two intensities',/, &
           '      is less than this number then the program treats such intentities as uncorrelated.',/,/,/, &  
           '**    When correlation is present between peaks the Monte Carlo integration technique is',/, &
           '      executed. max-Monte-Carlo-iterations is the maximum number of Monte Carlo iterations',/, &
           '      executed to bring the accuracy below the tolerance parameter. Like the correlation-',/, &
           '      cutoff parameter the tolerance represents a percentage value.') 
           
    close(13)


    sysreturn=SYSTEM('ExtSym.exe')
	      
end subroutine run_extsym