module write_out_pattern
use reflection_module
implicit none

  public :: cal_pattern
  

  integer, parameter, private :: db = kind(1.0)  
  !integer, parameter, private :: db = kind(1.d0)
  
  integer, parameter, private :: max_peaks_associated_with_each_i = 500  

  type pattern
    integer, dimension(:,:), allocatable :: which_peaks_contribute_to_which_i
    integer, dimension(:), allocatable :: num_peaks_to_each_i
    
    real(db), dimension(:), allocatable :: y_cal
  end type pattern
  
  ! you can make the type pattern private, but I have temporarely forgot how
  ! to do this


contains

  !
  ! subroutine quickly written for writing out the pattern
  ! for trying to understand the GSAS to Extsym extracted intensities
  ! plus their associated calculated standard deviations
  !
  function cal_pattern(refs, data_in, filename) result(scale)
    type(reflections), intent(in) :: refs
    type(data_container), intent(in) :: data_in
    character(*), intent(in) :: filename
    double precision :: scale

    integer :: reflection_in_focus  ! used in loop below
    integer :: i_in_profile  ! the store the relative position of the i'te data point
                             ! relative to a give profile_val array (which all starts from i=1)  
    
    integer :: num_refs  ! number of reflections
    integer :: num_data  ! number of data points
    integer :: i, j, jj
    
    type(pattern) :: l_pattern  ! l is here shorthand for local, i.e. this pattern is local to this file
    
    num_refs = size(refs%h)
    num_data = size(data_in%x_obs)

    
    ! allocate the local pattern
    
    allocate( l_pattern%y_cal( num_data ) )
    allocate( l_pattern%which_peaks_contribute_to_which_i( num_data, max_peaks_associated_with_each_i ) )
    allocate( l_pattern%num_peaks_to_each_i( num_data ) )
    l_pattern%y_cal = 0.0
    l_pattern%num_peaks_to_each_i = 0
    
    
    ! Find out which reflections contributes to which data points
    
    do j = 1, num_refs
      do i = refs%profile_start(j), refs%profile_end(j)
         l_pattern%num_peaks_to_each_i(i) = l_pattern%num_peaks_to_each_i(i) + 1
         l_pattern%which_peaks_contribute_to_which_i(i, l_pattern%num_peaks_to_each_i(i)) = j
      end do
    end do
  
  
    ! Now ready to calculate the pattern
    
    do i = 1, num_data
      do jj = 1, l_pattern%num_peaks_to_each_i(i)  ! sum over # refs contributing to the i'th data point
        reflection_in_focus = l_pattern%which_peaks_contribute_to_which_i(i,jj)
        i_in_profile = i + 1 - refs%profile_start(reflection_in_focus) 
        if ( i_in_profile < 1 .or. i_in_profile > &
          refs%profile_end(reflection_in_focus)-refs%profile_start(reflection_in_focus)+1) then
          write(*,*) "ERROR in subroutine cal_pattern"
          write(*,*) "None sensible profile index value found"
          stop
        end if
        
        l_pattern%y_cal(i) = l_pattern%y_cal(i) + refs%Iout(reflection_in_focus) * &
          refs%lor(reflection_in_focus) * refs%profile_vals(reflection_in_focus,i_in_profile) 
      end do
    end do
  

    ! write out approximate scale factor
    
    !write(*,*) sum(l_pattern%y_cal) / sum(l_pattern%y_cal**2 / data_in%y_obs)
    scale = sum(l_pattern%y_cal*data_in%y_obs) / sum(l_pattern%y_cal**2)
    

    ! write the calculated pattern
    
    !open(10,file=trim(filename),status='unknown')    
    
    !write(10,*) num_data

    !do i=1,num_data
    !  write(10,*) data_in%x_obs(i),l_pattern%y_cal(i)
    !enddo
    !close(10)    


  end function cal_pattern
  
    
end module write_out_pattern
